@@ -1,9 +1,9 @@
 package Mojolicious::Plugin::SPNEGO;
 use Mojo::Base 'Mojolicious::Plugin';
 use Net::LDAP::SPNEGO;
-use IO::Socket::INET;
+use IO::Socket::Timeout;
 
-our $VERSION = '0.3.4';
+our $VERSION = '0.3.5';
 
 my %cCache;
 
